# AddSelect

> 2.0.2

A jQuery plugin that replaces the native `<select>` element.

## Importing
Because this is a jQuery plugin, jQuery must be first imported before this plugin. Any version of jQuery should work.

```HTML
<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.1.0/jquery.min.js"></script>
```

Then copy addSelect.js and addSelect.css from the distribution (dist) directory into your project and import it into your page.

```HTML
<link rel='stylesheet' href='path/to/addSelect.css' />
<script src='path/to/addSelect.js'></script>
```

### Theming
The CSS was compiled from Sass (SCSS), you can change the color and the theme by editing the variables in src/addSelect.scss, the colors can be set to any color and $theme can be set to "dark" or "light". After making your changes you will need to recompile the SASS, if you do not have sass installed on your system visit [SassMeister.com](http://www.sassmeister.com/) for an easy to use online compiler (you will need to manually import the partials).

### Obj.JS
This plugin is built using the [Obj.JS 2.1+ framework](https://github.com/addui/ObjJS), but it is included in the distribution JS file (dist/addSelect.js). If you are already using Obj.JS on your page you should import the JS file from source instead (src/addSelect.js) to avoid loading duplicate code.

## How to Use
Create a select element as you normally would, except give it a `data-addui` attribute with a value of `"select"`.

```HTML
<select data-addui='select'>
  <option>Option 1</option>
  <option>Option 2</option>
  <option>Option 3</option>
</select>
```

![](res/basic.gif)


### Multiple
Add the `mutliple` attribute to the `<select>` element to allow for the selection of multiple options.

```HTML
<select data-addui='select' multiple >
  <option>Option 1</option>
  <option>Option 2</option>
  <option>Option 3</option>
</select>
```

![](res/multiple.gif)

### Required
Add the `required` attribute to the `<select>` element to require at least one option be selected.

```HTML
<select data-addui='select' required >
  <option>Option 1</option>
  <option>Option 2</option>
  <option>Option 3</option>
</select>
```

![](res/required.gif)

### Placeholder
Add the `placeholder` attribute to the `<select>` element to use a custom placeholder.

```HTML
<select data-addui='select' placeholder='Choose one already' >
  <option>Option 1</option>
  <option>Option 2</option>
  <option>Option 3</option>
</select>
```

![](res/placeholder.png)

## Settings
This plugin can take the following settings:

- **max**
  - The maximum number of options that can be selected at once.
  - *default =* `1`
- **min**
  - The minimum number of options that must be selected.
  - *default =* `0` (when not required), `1` (when required)
- **id**
  - The **id** attribute that is assigned to the `<input>` element.
- **name**
  - The **name** attribute that is assigned to the `<input>` element.
- **class**
  - The **class** that should be given to the widget.
- **placeholder**
  - The placeholder text that should be used when no value is selected.
  - *default =* `"Choose an Option"`
- **closeOnSelect**
  - `true` = The widget will be closed when an option is selected.
  - `false` = The widget will not be close when an option is selected.
  - *default =* `true` when not multiple, `false` when multiple.

These options are set automatically from the attributes of the `<select>` element, but can be overwritten of explicitly set by giving it a `data-{setting name}="{setting value}"` attribute.

#License

This software is property of [**Dustin Poissant**](http://github.com/dustinpoissat).

This software is distributed AS-IS with no warranties/guarantees either expressed or implied.

This software is Licensed under [CC BY-NC-SA 3.0 US](https://creativecommons.org/licenses/by-nc-sa/3.0/us/).
